@@ -43,11 +43,15 @@ def load_config(ctx: click.Context, param: click.Parameter, value: str) -> None:
     ctx.default_map = config
 
 
-def set_verbosity(ctx: click.Context, param: click.Parameter, value: int) -> int:
+def set_verbosity(value: int) -> None:
     level = settings.get_log_level(verbosity=value)
     logging.basicConfig(level=level)
     logger.info(f"Log level set to {logging.getLevelName(level)}")
-    return value
+
+
+def set_umask(umask: Optional[int]) -> None:
+    if umask is not None:
+        os.umask(umask)
 
 
 @contextlib.contextmanager
@@ -66,6 +70,21 @@ def print_version(ctx, __, value):
     ctx.exit()
 
 
+def parse_octal(value: Optional[str]) -> Optional[int]:
+    if not value:
+        return None
+    return int(value, base=8)
+
+
+def click_octal(_, __, value: Optional[str]) -> Optional[int]:
+    return parse_octal(value)
+
+
+def repr_octal(value: Optional[int]) -> Optional[str]:
+    # #05o means octal with 5 digits (0o octal prefix included)
+    return f"{value:#05o}" if value is not None else None
+
+
 @click.group(context_settings=CONTEXT_SETTINGS)
 @click.pass_context
 @click.option(
@@ -121,12 +140,10 @@ def print_version(ctx, __, value):
     help="Render templated values",
 )
 @click.option(
-    "-v",
-    "--verbose",
-    is_eager=True,
-    callback=set_verbosity,
-    count=True,
-    help="Use multiple times to increase verbosity",
+    "--umask", callback=click_octal, help="Set umask for newly created files.",
+)
+@click.option(
+    "-v", "--verbose", count=True, help="Use multiple times to increase verbosity",
 )
 @click.option(
     "--config-file",
@@ -145,7 +162,7 @@ def print_version(ctx, __, value):
     is_eager=True,
 )
 @handle_errors()
-def cli(ctx: click.Context, **kwargs) -> None:
+def cli(ctx: click.Context, verbose: int, umask: int, **kwargs) -> None:
     """
     Interact with a Vault. See subcommands for details.
 
@@ -154,7 +171,8 @@ def cli(ctx: click.Context, **kwargs) -> None:
 
     """
     kwargs.pop("config_file")
-    verbose = kwargs.pop("verbose")
+    set_verbosity(verbose)
+    set_umask(umask)
 
     assert ctx.default_map  # make mypy happy
     kwargs.update(extract_special_args(ctx.default_map, os.environ))
@@ -162,7 +180,8 @@ def cli(ctx: click.Context, **kwargs) -> None:
     # There might still be files to read, so let's do it now
     kwargs = settings.read_all_files(kwargs)
     saved_settings = kwargs.copy()
-    saved_settings.update({"verbose": verbose})
+
+    saved_settings.update({"verbose": verbose, "umask": repr_octal(umask)})
 
     ctx.obj = client.get_client_class()(**kwargs)  # type: ignore
     ctx.obj.auth()
